@@ -1,6 +1,6 @@
 package SVN::Hooks;
 # ABSTRACT: Framework for implementing Subversion hooks
-$SVN::Hooks::VERSION = '1.30';
+$SVN::Hooks::VERSION = '1.33';
 use strict;
 use warnings;
 
@@ -28,6 +28,9 @@ sub run_hook {
 
     $Repo = $repo_path;
 
+    # Allow all hooks assume they execute on the repository's root directory
+    chdir $repo_path or die "cannot chdir to $repo_path: $!\n";
+
     # Reload all configuration files
     foreach my $conf (@Conf_Files) {
 	my $conffile = file_name_is_absolute($conf) ? $conf : catfile($Repo, $conf);
@@ -35,7 +38,7 @@ sub run_hook {
 
         # The configuration file must be evaluated in the main:: namespace
 	package main;
-$main::VERSION = '1.30';
+$main::VERSION = '1.33';
 unless (my $return = do $conffile) {
 	    die "couldn't parse '$conffile': $@\n" if $@;
 	    die "couldn't do '$conffile': $!\n"    unless defined $return;
@@ -53,7 +56,7 @@ unless (my $return = do $conffile) {
 	$repo_path = SVN::Look->new($repo_path, '-r' => $args[0]);
     }
 
-    foreach my $hook (@{$Hooks{$hook_name}}) {
+    foreach my $hook (@{$Hooks{$hook_name}{list}}) {
 	if (is_code_ref($hook)) {
 	    $hook->($repo_path, @args);
 	} elsif (is_array_ref($hook)) {
@@ -70,11 +73,14 @@ unless (my $return = do $conffile) {
 
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
 
-# post-commit(SVN::Look)
+# post-commit(SVN::Look, revision, txn-name)
 
 sub POST_COMMIT (&) {
     my ($hook) = @_;
-    push @{$Hooks{'post-commit'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'post-commit'}{set}{$hook}) {
+        push @{$Hooks{'post-commit'}{list}},
+            ($Hooks{'post-commit'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
@@ -82,15 +88,21 @@ sub POST_COMMIT (&) {
 
 sub POST_LOCK (&) {
     my ($hook) = @_;
-    push @{$Hooks{'post-lock'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'post-lock'}{set}{$hook}) {
+        push @{$Hooks{'post-lock'}{list}},
+            ($Hooks{'post-lock'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
-# post-revprop-change(SVN::Look, username, property-name, action)
+# post-revprop-change(SVN::Look, revision, username, property-name, action)
 
 sub POST_REVPROP_CHANGE (&) {
     my ($hook) = @_;
-    push @{$Hooks{'post-revprop-change'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'post-revprop-change'}{set}{$hook}) {
+        push @{$Hooks{'post-revprop-change'}{list}},
+            ($Hooks{'post-revprop-change'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
@@ -98,15 +110,21 @@ sub POST_REVPROP_CHANGE (&) {
 
 sub POST_UNLOCK (&) {
     my ($hook) = @_;
-    push @{$Hooks{'post-unlock'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'post-unlock'}{set}{$hook}) {
+        push @{$Hooks{'post-unlock'}{list}},
+            ($Hooks{'post-unlock'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
-# pre-commit(SVN::Look)
+# pre-commit(SVN::Look, txn-name)
 
 sub PRE_COMMIT (&) {
     my ($hook) = @_;
-    push @{$Hooks{'pre-commit'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'pre-commit'}{set}{$hook}) {
+        push @{$Hooks{'pre-commit'}{list}},
+            ($Hooks{'pre-commit'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
@@ -114,15 +132,21 @@ sub PRE_COMMIT (&) {
 
 sub PRE_LOCK (&) {
     my ($hook) = @_;
-    push @{$Hooks{'pre-lock'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'pre-lock'}{set}{$hook}) {
+        push @{$Hooks{'pre-lock'}{list}},
+            ($Hooks{'pre-lock'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
-# pre-revprop-change(SVN::Look, username, property-name, action)
+# pre-revprop-change(SVN::Look, revision, username, property-name, action)
 
 sub PRE_REVPROP_CHANGE (&) {
     my ($hook) = @_;
-    push @{$Hooks{'pre-revprop-change'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'pre-revprop-change'}{set}{$hook}) {
+        push @{$Hooks{'pre-revprop-change'}{list}},
+            ($Hooks{'pre-revprop-change'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
@@ -130,15 +154,29 @@ sub PRE_REVPROP_CHANGE (&) {
 
 sub PRE_UNLOCK (&) {
     my ($hook) = @_;
-    push @{$Hooks{'pre-unlock'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'pre-unlock'}{set}{$hook}) {
+        push @{$Hooks{'pre-unlock'}{list}},
+            ($Hooks{'pre-unlock'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
-# start-commit(repos-path, username, capabilities, txt-name)
+# <  1.8: start-commit(repos-path, username, capabilities)
+# >= 1.8: start-commit(repos-path, username, capabilities, txn-name)
+
+# Subversion 1.8 added a txn-name argument to the start-commit. However it's
+# only good to get at the commit properties but not to know about the files
+# being changed by the commit, which would allow us to use the start-commit
+# to perform many of the checks that we perform currently in the pre-commit
+# hook. So, for now I'm not going to use the new argument to construct a
+# SVN::Look object, since it is mostly useless anyway.
 
 sub START_COMMIT (&) {
     my ($hook) = @_;
-    push @{$Hooks{'start-commit'}}, sub { $hook->(@_); };
+    unless (exists $Hooks{'start-commit'}{set}{$hook}) {
+        push @{$Hooks{'start-commit'}{list}},
+            ($Hooks{'start-commit'}{set}{$hook} = sub { $hook->(@_); });
+    }
     return;
 }
 
@@ -158,7 +196,7 @@ SVN::Hooks - Framework for implementing Subversion hooks
 
 =head1 VERSION
 
-version 1.30
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -169,7 +207,7 @@ A single script can implement several hooks:
 	use SVN::Hooks;
 
 	START_COMMIT {
-	    my ($repo_path, $username, $capabilities, $txt_name) = @_;
+	    my ($repo_path, $username, $capabilities, $txn_name) = @_;
 	    # ...
 	};
 
@@ -241,6 +279,11 @@ their hook program runs fine by hand, but doesn't work when run by
 Subversion. Be sure to explicitly set any necessary environment
 variables in your hook program and/or use absolute paths to programs."
 
+Not even the current directory where the hooks run is specified by
+Subversion. However, the hooks executed by the SVN::Hooks framework run with
+their currect directory set to the repository's root directory in the
+server. This can be useful sometimes.
+
 There are several useful hook scripts available elsewhere
 L<http://svn.apache.org/repos/asf/subversion/trunk/contrib/hook-scripts/>,
 mainly for those three associated with the commit operation. However,
@@ -346,7 +389,7 @@ L<SVN::Look> documentation to know how to use it.)
 
 =item * PRE_UNLOCK(repos-path, path, username, lock-token, break-unlock-flag)
 
-=item * START_COMMIT(repos-path, username, capabilities, txt-name)
+=item * START_COMMIT(repos-path, username, capabilities, txn-name)
 
 =back
 
@@ -359,7 +402,7 @@ This is an example of a script implementing two hooks:
 	# ...
 
 	START_COMMIT {
-	    my ($repos_path, $username, $capabilities, $txt_name) = @_;
+	    my ($repos_path, $username, $capabilities, $txn_name) = @_;
 
 	    exists $committers{$username}
 		or die "User '$username' is not allowed to commit.\n";
@@ -555,7 +598,7 @@ called, like this:
 
 =over
 
-=item * start-commit repo-path user capabilities txt-name
+=item * start-commit repo-path user capabilities txn-name
 
 =item * pre-commit repo-path txn
 
@@ -590,7 +633,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
