@@ -1,13 +1,13 @@
 package SVN::Hooks::CheckJira;
 # ABSTRACT: Integrate Subversion with the JIRA ticketing system.
-$SVN::Hooks::CheckJira::VERSION = '1.30';
+$SVN::Hooks::CheckJira::VERSION = '1.33';
 use strict;
 use warnings;
 
 use Carp;
 use Data::Util qw(:check);
 use SVN::Hooks;
-use JIRA::Client;
+use JIRA::REST;
 
 use Exporter qw/import/;
 my $HOOK = 'CHECK_JIRA';
@@ -126,19 +126,20 @@ sub _pre_checks {
     # Grok and check each JIRA issue
     my @issues;
     foreach my $key (@$keys) {
-	my $issue = eval {$JIRA->getIssue($key)};
+	my $issue = eval {$JIRA->GET("/issue/$key")};
 	if ($opts->{valid}) {
 	    croak "$HOOK: issue $key is not valid: $@\n" if $@;
 	}
 	$issue or next;
 	if ($opts->{unresolved}) {
 	    croak "$HOOK: issue $key is already resolved.\n"
-		if defined $issue->{resolution};
+		if defined $issue->{fields}{resolution};
 	}
 	if ($opts->{by_assignee}) {
 	    my $author = $svnlook->author();
-	    croak "$HOOK: committer ($author) is different from issue ${key}'s assignee ($issue->{assignee}).\n"
-		if $author ne $issue->{assignee};
+            my $assignee = $issue->{fields}{assignee}{name};
+	    croak "$HOOK: committer ($author) is different from issue ${key}'s assignee ($assignee).\n"
+		if $author ne $assignee;
 	}
 	if (my $check = $opts->{check_one}) {
 	    $check->($JIRA, $issue, $svnlook);
@@ -209,7 +210,7 @@ sub _check_if_needed {
 
 		# Connect to JIRA if not yet connected.
 		unless (defined $JIRA) {
-		    $JIRA = eval {JIRA::Client->new($BaseURL, $Login, $Passwd)};
+		    $JIRA = eval {JIRA::REST->new($BaseURL, $Login, $Passwd)};
 		    croak "CHECK_JIRA_CONFIG: cannot connect to the JIRA server: $@\n" if $@;
 		}
 
@@ -248,7 +249,7 @@ SVN::Hooks::CheckJira - Integrate Subversion with the JIRA ticketing system.
 
 =head1 VERSION
 
-version 1.30
+version 1.33
 
 =head1 DESCRIPTION
 
@@ -276,7 +277,7 @@ to match against the commit logs in order to extract the list of JIRA
 issue keys. By default, the JIRA keys are looked for in the whole
 commit log, which is equivalent to qr/(.*)/. Sometimes this can be
 suboptimal because the user can introduce in the message some text
-that inadvertently looks like a JIRA issue key whithout being so. With
+that inadvertently looks like a JIRA issue key without being so. With
 this argument, the log message is matched against the REGEXP and only
 the first matched group (i.e., the part of the message captured by the
 first parenthesis (C<$1>)) is used to look for JIRA issue keys.
@@ -309,7 +310,7 @@ The available options are the following:
 
 =item projects => 'PROJKEYS'
 
-By default, the commiter can reference any JIRA issue in the commit
+By default, the committer can reference any JIRA issue in the commit
 log. You can restrict the allowed keys to a set of JIRA projects by
 specifying a comma-separated list of project keys to this option.
 
@@ -332,8 +333,8 @@ false value to this option.
 
 =item by_assignee => [01]
 
-By default, the commiter can reference any valid JIRA issue. Passing a
-true value to this option you require that the commiter can only
+By default, the committer can reference any valid JIRA issue. Passing a
+true value to this option you require that the committer can only
 reference issues to which she is the current assignee.
 
 =item check_one => CODE-REF
@@ -344,9 +345,19 @@ each referenced issue with three arguments:
 
 =over
 
-=item the JIRA::Client object used to talk to the JIRA server.
+=item the JIRA::REST object used to talk to the JIRA server.
 
-=item the RemoteIssue object representing the issue.
+Note that up to version 1.26 of SVN::Hooks::CheckJira this used to be a
+JIRA::Client object, which uses JIRA's SOAP API which was deprecated on JIRA
+6.0 and won't be available anymore on JIRA 7.0.
+
+If you have code relying on the JIRA::Client module you're advised to
+rewrite it using the JIRA::REST module. As a stopgap measure you can
+disregard the JIRA::REST object and create your own JIRA::Client object. For
+this you only need the three arguments you've passed to the
+CHECK_JIRA_CONFIG directive.
+
+=item the hash representing the issue.
 
 =item the SVN::Look object used to grok information about the commit.
 
@@ -355,20 +366,19 @@ each referenced issue with three arguments:
 The subroutine must simply return with no value to indicate success
 and must die to indicate failure.
 
-Plese, read the JIRA::Client and SVN::Look modules documentation to
+Plese, read the JIRA::REST and SVN::Look modules documentation to
 understand how to use these objects.
 
 =item check_all => CODE-REF
 
-Sometimes checking each issue separatelly isn't enough. You may want
-to check some relation among all the referenced issues. In this case,
-pass a code reference to this option. It will be called once for the
-commit. Its first argument is the JIRA::Client object used to talk to
-the JIRA server. The following arguments are references to RemoteIssue
-objects for every referenced issue. The last argument is the SVN::Look
-object used to grok information about the commit. The subroutine must
-simply return with no value to indicate success and must die to
-indicate failure.
+Sometimes checking each issue separatelly isn't enough. You may want to
+check some relation among all the referenced issues. In this case, pass a
+code reference to this option. It will be called once for the commit. Its
+first argument is the JIRA::REST object used to talk to the JIRA server. The
+following arguments are references to hashes representing every referenced
+issue. The last argument is the SVN::Look object used to grok information
+about the commit. The subroutine must simply return with no value to
+indicate success and must die to indicate failure.
 
 =item check_all_svnlook => CODE-REF
 
@@ -381,7 +391,7 @@ information about the commit. The rest of the arguments are the same.
 This is not a check, but an opportunity to perform some action after a
 successful commit. The code reference passed will be called once
 during the post-commit hook phase. Its first argument is the
-JIRA::Client object used to talk to the JIRA server. The second
+JIRA::REST object used to talk to the JIRA server. The second
 argument is the SVN::Look object that can be used to inspect all the
 information about the commit proper.  The following arguments are the
 JIRA keys mentioned in the commit log message. The value returned by
@@ -428,11 +438,11 @@ commit, do this:
 
 The C<'post_action'> pseudo-check can be used to interact with the
 JIRA server after a successful commit. For instance, you may want to
-add a comment to each refered issue like this:
+add a comment to each referred issue like this:
 
     # This routine returns a closure that can be passed to
     # post_action.  The closure receives a string to be added as a
-    # comment to each issue refered to by the commit message. The
+    # comment to each issue referred to by the commit message. The
     # commit info can be interpolated inside the comment using the
     # SVN::Look method names inside angle brackets.
 
@@ -444,7 +454,7 @@ add a comment to each refered issue like this:
             # into the $svnlook reference
 	    $format =~ s/\{(\w+)\}/"\$svnlook->$1()"/eeg;
             for my $key (@keys) {
-                $jira->addComment($key, $format);
+                $jira->POST("/issue/$key/comment", undef, { body => $format });
             }
         }
     }
@@ -469,13 +479,25 @@ don't want to reject Subversion commits in this period.
 
 =for Pod::Coverage post_commit pre_commit
 
+=head1 SEE ALSO
+
+=over
+
+=item * L<JIRA::REST>
+
+=item * L<JIRA::Client>
+
+=item * L<JIRA SOAP API deprecation notice|https://developer.atlassian.com/display/JIRADEV/SOAP+and+XML-RPC+API+Deprecated+in+JIRA+6.0>
+
+=back
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
