@@ -1,6 +1,6 @@
 package SVN::Hooks::Generic;
 # ABSTRACT: Implement generic checks for all Subversion hooks.
-$SVN::Hooks::Generic::VERSION = '1.30';
+$SVN::Hooks::Generic::VERSION = '1.33';
 use strict;
 use warnings;
 
@@ -31,7 +31,10 @@ sub GENERIC {
 	}
 	foreach my $foo (@$functions) {
 	    is_code_ref($foo) or die "$HOOK: hook '$hook' should be mapped to CODE-refs.\n";
-	    push @{$SVN::Hooks::Hooks{$hook}}, sub { $foo->(@_); };
+            unless (exists $SVN::Hooks::Hooks{$hook}{set}{$foo}) {
+                push @{$SVN::Hooks::Hooks{$hook}{list}},
+                    ($SVN::Hooks::Hooks{$hook}{set}{$foo} = sub { $foo->(@_); });
+            }
 	}
     }
 
@@ -52,7 +55,7 @@ SVN::Hooks::Generic - Implement generic checks for all Subversion hooks.
 
 =head1 VERSION
 
-version 1.30
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -129,7 +132,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
